<?php
# When you insert a value for one of the following variables, it will
# always be used by hoteldruid to connect to the database

# Database type, values can be "sqlite", "mysql" or "postgresql"
$HOTELD_DB_TYPE = "";

# Database name
$HOTELD_DB_NAME = "";

# Database connection host
$HOTELD_DB_HOST = "";

# Database connection port
$HOTELD_DB_PORT = "";

# Username to authenticate with database
$HOTELD_DB_USER = "";

# Password to authenticate with database
$HOTELD_DB_PASS = "";

#  Prefix used in front of all table names
$HOTELD_TAB_PRE = "";


?>
